#!/usr/bin/env node
import program from "commander";
import chalk from "chalk";
import fs from "fs";
import path from "path";
//import inquirer from "inquirer";
import getAppDataPath from "appdata-path";

interface Snippet {
  prefix: string[];
  body: string[];
  description: string;
}

const packageJson = require("../package.json");

program.version(packageJson.version);

program.option("-i, --install", "Install snippets").action((options: any) => {
  const toPath = path.join(
    getAppDataPath(),
    "Code",
    "User",
    "snippets",
    "typescriptreact.json"
  );

  fs.writeFileSync(
    toPath,
    JSON.stringify(
      {
        ...createSnippet("React functional component", "rc"),
        ...createSnippet("NextJS page", "nextpage"),
        ...createSnippet("CSS prop", "cssp"),
        ...createSnippet("Tailwind utility classes", "tw"),
        ...createSnippet("MobX property", "mx"),
        ...createSnippet("useState", "us"),
      },
      undefined,
      2
    )
  );

  console.log("Installing snippets to:", toPath);

  const toPath2 = path.join(
    getAppDataPath(),
    "Code",
    "User",
    "snippets",
    "typescript.json"
  );

  fs.writeFileSync(
    toPath2,
    JSON.stringify(
      {
        ...createSnippet("MobX property", "mx"),
      },
      undefined,
      2
    )
  );

  console.log("Installing snippets to:", toPath2);
});

function createSnippet(name: string, templateFile: string) {
  const fromPath = path.join(__dirname, "../snippets/", templateFile + ".txt");
  let snippetContent = fs.readFileSync(fromPath, "utf-8");

  snippetContent = snippetContent.replace(
    /ComponentName/g,
    "${1:ComponentName}"
  );

  snippetContent = snippetContent.replace(/CssContent/g, "${1:display: flex;}");

  const snippetFull = {
    [name]: {
      prefix: [templateFile],
      body: [snippetContent],
      description: templateFile,
    },
  };
  return snippetFull;
}

program.parse(process.argv);
